
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: CanGuildBankRepair, GetGuildBankWithdrawMoney, GetMoney, GetRepairAllCost, IsInGuild, RepairAllItems

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(select(2, ...)) -- AddOn, Border, Constants, Database
local M = A:NewModule("Automation Repair")

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:RegisterEvent("MERCHANT_SHOW")
end

-- Determine whether character repair is available.
function M:CanCharacterRepair(repairAllCost)
	return self.config.useCharacterGold and GetMoney() >= repairAllCost
end

-- Determine whether guild repair is available.
function M:CanGuildRepair(repairAllCost)
	return self.config.useGuildGold
		and IsInGuild()
		and CanGuildBankRepair()
		and ((GetGuildBankWithdrawMoney() == -1) or (GetGuildBankWithdrawMoney() >= repairAllCost))
end

-- Determine whether a funding source is available.
function M:HasFundingSource()
	return self.config.useCharacterGold or self.config.useGuildGold
end

-------------------------------------------------------------------------------
-- Events
-------------------------------------------------------------------------------

-- Repair all equipped and inventory items using the guild or player's funds.
function M:MERCHANT_SHOW()
	if (not self:HasFundingSource()) then return end
	local repairAllCost, canRepair = GetRepairAllCost()
	if (not canRepair) then return end

	if self:CanGuildRepair(repairAllCost) then
		RepairAllItems(1)
		A.PrintF("You withdrew %s from the guild bank for repairs.", A.FormatMoney(repairAllCost))
	elseif self:CanCharacterRepair(repairAllCost) then
		RepairAllItems()
		A.PrintF("You spent %s on repairs.", A.FormatMoney(repairAllCost))
	else
		A.Print("You do not have enough gold for repairs.")
	end
end
