
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: BROWSE_NO_RESULTS, C_CurrencyInfo, COPPER_AMOUNT_SYMBOL, CURRENCY, FormatLargeNumber, GameTooltip, HandleModifiedItemClick, IsControlKeyDown, IsShiftKeyDown, ToggleAllBags, ToggleCharacter

local GetMoney = GetMoney

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(SixUI) -- AddOn, Border, Constants, Database
local M = A:NewModule("Display Currency")
local O = LibStub("LibDataBroker-1.1"):NewDataObject("SixUI Currency", {
	type = "data source",
	text = "0 c",
	value = "0",
	suffix = COPPER_AMOUNT_SYMBOL,
	label = "Currency",
})
local Tooltip = LibStub("SixTooltip-1.0"):CreateTooltip({
	columnJustification = {"LEFT", "RIGHT", "LEFT"},
	font = C.TEXT_REGULAR,
	headerFont = C.TEXT_LARGE,
	key = "SixUI Currency",
	numColumns = 3,
	separatorHeight = C.TOOLTIP_SEPARATOR_HEIGHT,
})

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:RegisterEvent("PLAYER_MONEY", "Update")
	self:Update()
end

function M:Update()
	O.text, O.value, O.suffix = A.FormatMoney(GetMoney())
end

-------------------------------------------------------------------------------
-- DataObject
-------------------------------------------------------------------------------

function O.OnEnter(frame)
	if C.IS_RETAIL then
		if frame then
			Tooltip:UpdateConfig({anchor = frame})
		end

		Tooltip:Show()
	end
end

function O.OnClick(frame, button)
	if C.IS_RETAIL then
		ToggleCharacter("TokenFrame")
	else
		ToggleAllBags()
	end
end

-------------------------------------------------------------------------------
-- Tooltip
-------------------------------------------------------------------------------

local function Currency_OnEnter(self, index)
	GameTooltip:SetOwner(self, "ANCHOR_RIGHT")
	GameTooltip:SetCurrencyToken(index)
end

local function Currency_OnLeave(self)
	GameTooltip:Hide()
end

local function Currency_OnClick(self, index, button)
	if button == "LeftButton" then
		if IsShiftKeyDown() then
			A.OpenEditBox()
			HandleModifiedItemClick(C_CurrencyInfo.GetCurrencyListLink(index))
		elseif IsControlKeyDown() then
			C_CurrencyInfo.SetCurrencyUnused(index, 1)
			Tooltip:Refresh()
		end
	end
end

function Tooltip:OnShow()
	self:AddHeader(CURRENCY)
	self:AddSeparator(C.TOOLTIP_SEPARATOR_HEIGHT)

	for index = 1, C_CurrencyInfo.GetCurrencyListSize() do
		self:AddCurrency(index)
	end

	if self:GetLineCount() < 3 then
		self:AddLine(BROWSE_NO_RESULTS)
	end
end

function Tooltip:AddCurrency(index)
	local currency = C_CurrencyInfo.GetCurrencyListInfo(index)
	if currency.isHeader or currency.isTypeUnused then return end
	local line = self:AddLine(currency.name, FormatLargeNumber(currency.quantity or 0), "|T" .. (currency.iconFileID or "") .. ":16:16:0:0:64:64:4:60:4:60|t")

	self:SetLineScript(line, "OnEnter", Currency_OnEnter, index)
	self:SetLineScript(line, "OnLeave", Currency_OnLeave)
	self:SetLineScript(line, "OnMouseDown", Currency_OnClick, index)
end
